@@ -1,6 +1,7 @@
 import asyncio
 import aioesphomeapi
 from aioesphomeapi.core import APIConnectionError
+from aioesphomeapi.model import UserService
 from . import pod
 from typing import cast
 
@@ -8,7 +9,7 @@ from typing import cast
 SERVICE_TYPE = "_esphomelib._tcp.local."
 
 
-class ESPHome(object):
+class ESPHome():
 
     def __init__(self, out, id, mdns, service_name):
 
@@ -57,8 +58,7 @@ class ESPHome(object):
     async def connect(self):
 
         pod.eprint(f'ESP Connecting {self.service_name}')
-        info = await self.mdns.get_info(
-                SERVICE_TYPE, f'{self.service_name}.{SERVICE_TYPE}')
+        info = await self.mdns.get_info(SERVICE_TYPE, self.service_name)
 
         assert info is not None
         hosts = info.parsed_scoped_addresses()
@@ -78,7 +78,16 @@ class ESPHome(object):
                         "state": [str(state.key), state.state]
                         })
 
+        def esp_subscribe_ha_state(entity_id, attribute):
+            self.out.write_msg(
+                    id=self.id,
+                    data={
+                        "service-name": self.service_name,
+                        "ha-state-subscribe": [entity_id, attribute]
+                        })
+
         await self.cli.subscribe_states(esp_change_callback)
+        await self.cli.subscribe_home_assistant_states(esp_subscribe_ha_state)
 
     async def update_services(self):
 
@@ -93,6 +102,7 @@ class ESPHome(object):
             service_details[str(s.key)] = \
                 {**s.to_dict(), **{"type": "user-defined-service"}}
 
+        self.service_details = service_details
         self.out.write_msg(
                 id=self.id,
                 data={
@@ -109,4 +119,15 @@ class ESPHome(object):
         await self.cli.light_command(key, **params)
         self.out.write_msg(id=id, data={"success": True})
 
+    async def service_command(self, id, key, params):
+        svc = self.service_details[str(key)].copy()
+        svc.pop('type')
+        service = UserService(**svc)
+        await self.cli.execute_service(service, params)
+        self.out.write_msg(id=id, data={"success": True})
+
+    async def state_update(self, id, entity_id, attribute, state):
+        await self.cli.send_home_assistant_state(entity_id, attribute, state)
+        self.out.write_msg(id=id, data={"success": True})
+
 
